@@ -1,16 +1,11 @@
 <?php
-/* $Id: brazilian_portuguese-iso-8859-1.inc.php 10243 2007-04-02 16:55:39Z lem9 $ */
-
-/**
- * translated by: 
-   Airon Luis Pereira <aironp@pop.com.br> 
-*/ 
+/* $Id$ */
+/* translated by: Airon Luis Pereira <airon(dot)pereira(at)gmail(dot)com> */ 
 
 $charset = 'iso-8859-1'; 
-$text_dir = 'ltr'; 
+$text_dir = 'ltr';  // ('ltr' da esquerda para direita, 'rtl' da direita para esquerda)
 $number_thousands_separator = ','; 
 $number_decimal_separator = '.'; 
-
 // abreviaes para Byte, Kilo, Mega, Giga, Tera, Peta, Exa 
 $byteUnits = array('Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB'); 
 
@@ -18,7 +13,6 @@ $mysql_4_1_doc_lang = 'pt';
 
 $day_of_week = array('Dom', 'Seg', 'Ter', 'Qua', 'Qui', 'Sex', 'Sab'); 
 $month = array('Jan', 'Fev', 'Mar', 'Abr', 'Mai', 'Jun', 'Jul', 'Ago', 'Set', 'Out', 'Nov', 'Dez'); 
-
 // Veja http://www.php.net/manual/en/function.strftime.php para definir
 // as variveis abaixo
 $datefmt = '%B %d, %Y as %I:%M %p'; 
@@ -29,12 +23,12 @@ $strAbortedClients = 'Abortado';
 $strAccessDenied = 'Acesso negado'; 
 $strAccessDeniedCreateConfig = 'A provvel razo para isso  que voc no criou o arquivo de configurao. Voc deve usar o %1$ssetup script%2$s para criar um.';
 $strAccessDeniedExplanation = 'phpMyAdmin tentou se conectar no servidor MySQL e a conxo foi recusada. Voc deve checar o servidor, nome de usurio e senha no config.inc.php e se certificar que correspondam com as informaes fornecidas pelo administrador do servidor MySQL.'; 
-$strAction = 'Aes'; 
+$strAction = 'Ao'; 
 $strAddAutoIncrement = 'Adicionar valor AUTO_INCREMENT'; 
 $strAddClause = 'Adicionar %s';
 $strAddConstraints = 'Adicionar restries'; 
 $strAddDeleteColumn = 'Adicionar/Remover colunas'; 
-$strAddDeleteRow = 'Adicionar/Remover condies de busca'; 
+$strAddDeleteRow = 'Adicionar/Remover critrios de busca'; 
 $strAddFields = 'Adicionar %s campo(s)'; 
 $strAddHeaderComment = 'Adicionar comentrio pessoal no cabealho (\\n quebra linhas)'; 
 $strAddIntoComments = 'Adicionar nos comentrios'; 
@@ -72,7 +66,6 @@ $strAscending = 'Ascendente';
 $strAtBeginningOfTable = 'No incio da tabela'; 
 $strAtEndOfTable = 'No final da tabela'; 
 $strAttr = 'Atributos'; 
-$strAutodetect = 'Auto-detectar'; 
 $strAutomaticLayout = 'Leiaute automtico'; 
 
 $strBack = 'Voltar'; 
@@ -161,6 +154,7 @@ $strConnectionError = 'No pode conectar: configuraes invlidas.';
 $strConnections = 'Conexes'; 
 $strConstraintsForDumped = 'Restries para as tabelas dumpadas'; 
 $strConstraintsForTable = 'Restries para a tabela'; 
+$strControluserFailed = 'Conexo para controle do usurio como definido nas configuraes falhou.';
 $strCookiesRequired = 'Cookies devem estar ativos aps este ponto.'; 
 $strCopy = 'Copiar';
 $strCopyDatabaseOK = 'Banco de Dados %s copiado para %s'; 
@@ -186,8 +180,6 @@ $strCreationDates = 'Criar/Atualizar/Verificar datas';
 $strCriteria = 'Critrio'; 
 $strCroatian = 'Croata'; 
 $strCSV = 'CSV';
-$strCSVImportOptions = 'Opes CSV';
-$strCSVOptions = 'Opes CSV'; 
 $strCyrillic = 'Cirlico'; 
 $strCzechSlovak = 'Tcheco-Eslovquio'; 
 $strCzech = 'Tcheco'; 
@@ -197,7 +189,6 @@ $strDatabase = 'Banco de Dados';
 $strDatabaseEmpty = 'O nome do Banco de Dados est em branco!'; 
 $strDatabaseExportOptions = 'Opes de exportao do Banco de Dados'; 
 $strDatabaseHasBeenDropped = 'Banco de Dados %s foi eliminado.'; 
-$strDatabaseNoTable = 'Esse Banco de Dados no possui tabelas!'; 
 $strDatabases = 'Banco de Dados'; 
 $strDatabasesDropped = 'Banco de Dados %s foi eliminado com sucesso!'; 
 $strDatabasesStatsDisable = 'Disabilitar estatsticas'; 
@@ -243,9 +234,8 @@ $strDisplayOrder = 'Ordenado por:';
 $strDisplayPDF = 'Exibir esquema PDF'; 
 $strDoAQuery = 'Faa uma "consulta por exemplo" (coringa: "%")'; 
 $strDocSQL = 'DocSQL';
-$strDocSQLOptions = 'Opes DocSQL';
 $strDocu = 'Documentao'; 
-$strDoYouReally = 'Confirmar: '; 
+$strDoYouReally = 'Confirmar'; 
 $strDropDatabaseStrongWarning = 'Voc est prestes  DESTRUIR completamente o Banco de Dados!'; 
 $strDrop = 'Eliminar'; 
 $strDropUsersDb = 'Eliminar o Banco de Dados que possui o mesmo nome dos usurios.'; 
@@ -258,7 +248,7 @@ $strEdit = 'Editar';
 $strEditPDFPages = 'Editar Pginas PDF'; 
 $strEditPrivileges = 'Editar Privilgios'; 
 $strEffective = 'Efetivo'; 
-$strEmpty = 'Limpa'; 
+$strEmpty = 'Limpar'; 
 $strEmptyResultSet = 'MySQL retornou um conjunto vazio (ex. zero registros).'; 
 $strEnabled = 'Habilitado'; 
 $strEncloseInTransaction = 'Encapsular exportao numa transao'; 
@@ -267,7 +257,7 @@ $strEnd = 'Fim';
 $strEndRaw = 'FIM CRU'; 
 $strEngineAvailable = '%s est disponvel neste servidor MySQL.';
 $strEngineDisabled = '%s est desabilitado neste servidor MySQL.';
-$strEngines = 'Engines';
+$strEngines = 'Engines'; //sem traducao
 $strEngineUnsupported = 'Esse servidor MySQL no suporta o stored engine %s.';
 $strEnglish = 'Ingls'; 
 $strEnglishPrivileges = ' Nota: nomes de privilgios do MySQL so expressos em ingls '; 
@@ -280,8 +270,8 @@ $strErrorSaveTable = 'Erro ao salvar coordenada para o Designer.';
 $strEscapeWildcards = 'Coringas _ e % precisam ser precedidos com uma \ para serem usados literalmente'; 
 $strEsperanto = 'Esperanto';
 $strEstonian = 'Estoniano'; 
+$strEvent = 'Evento';
 $strExcelEdition = 'Edio do Excel'; 
-$strExcelOptions = 'Opes do Excel'; 
 $strExecuteBookmarked = 'Executar consulta marcada'; 
 $strExplain = 'Explicar SQL'; 
 $strExport = 'Exportar'; 
@@ -293,8 +283,8 @@ $strExtra = 'Extra';
 $strFailedAttempts = 'Tentativas falharam'; 
 $strField = 'Campo'; 
 $strFieldHasBeenDropped = 'Campo %s foi deletado'; 
+$strFieldInsertFromFileTempDirNotExists = 'Erro ao mover o arquivo carregado, veja FAQ 1.11';
 $strFields = 'Campos'; 
-$strFieldsEmpty = ' O campo count esta vazio! '; 
 $strFieldsEnclosedBy = 'Campos delimitados por'; 
 $strFieldsEscapedBy = 'Campos contornados por'; 
 $strFieldsTerminatedBy = 'Campos terminados por'; 
@@ -306,6 +296,7 @@ $strFileNameTemplateDescriptionServer = 'nome do servidor';
 $strFileNameTemplateDescriptionTable = 'nome da tabela';
 $strFileNameTemplate = 'Nome do arquivo do modelo'; 
 $strFileNameTemplateRemember = 'lembrar modelo'; 
+$strFiles = 'Arquivos';
 $strFileToImport = 'Arquivo para importar';
 $strFixed = 'fixo'; 
 $strFlushPrivilegesNote = 'Nota: O phpMyAdmin recebe os privilgios dos usurio diretamente da tabela de privilgios do MySQL. O contedo destas tabelas pode divergir dos privilgios que o servidor usa se alteraes manuais forem feitas nele. Neste caso, voc deve usar %sRELOAD PRIVILEGES%s antes de continuar..'; 
@@ -342,7 +333,7 @@ $strHasBeenCreated = 'foi criado.';
 $strHaveToShow = 'Deve escolher pelo menos uma coluna para exibir'; 
 $strHebrew = 'Hebreu'; 
 $strHelp = 'Ajuda';
-$strHexForBinary = 'Usar hexadecimal para campos binrios'; 
+$strHexForBLOB = 'Usar hexadecimal para BLOB';
 $strHide = 'Ocultar';
 $strHideShowAll = 'Ocultar/Exibir tudo';
 $strHideShowNoRelation = 'Ocultar/Exibir Tabelas sem relacionamento';
@@ -351,9 +342,7 @@ $strHome = 'Principal';
 $strHostEmpty = 'O nome do servidor est vazio!'; 
 $strHost = 'Servidor'; 
 $strHTMLExcel = 'Microsoft Excel 2000';
-$strHTMLExcelOptions = 'Opes de exportao: Microsoft Excel 2000';
 $strHTMLWord = 'Microsoft Word 2000';
-$strHTMLWordOptions = 'Opes de exportao: Microsoft Word 2000';
 $strHungarian = 'Hngaro'; 
 
 $strIcelandic = 'Islands'; 
@@ -369,14 +358,12 @@ $strImportFormat = 'Formato do arquivo importado';
 $strImport = 'Importar';
 $strImportSuccessfullyFinished = 'Importao finalizada com sucesso, %d consultas executadas.';
 $strIndexes = 'ndices'; 
+$strIndexesSeemEqual = 'Os seguintes ndices parecem ser idnticos e um deles deve ser removido:';
 $strIndexHasBeenDropped = 'ndice %s foi eliminado'; 
 $strIndex = 'ndice'; 
 $strIndexName = 'Nome do ndice:'; 
 $strIndexType = 'Tipo de ndice:'; 
-$strIndexWarningMultiple = 'Mais de uma %s chave foi criada para a coluna `%s`'; 
-$strIndexWarningPrimary = 'Chaves PRIMARY e INDEX no podem ser usadas juntas para a coluna `%s`'; 
 $strIndexWarningTable = 'Problemas com o ndice da tabela `%s`'; 
-$strIndexWarningUnique = 'Chaves UNIQUE e INDEX no podem ser usadas juntas para a coluna `%s`'; 
 $strInnoDBAutoextendIncrementDesc = 'O tamanho do incremento para extender o tamanho de um tamanho de tabela autoextendida quando ela comear  ficar cheia.';
 $strInnoDBAutoextendIncrement = 'Incremento autoextendido';
 $strInnoDBBufferPoolSizeDesc = 'O tamanho do buffer de memria que o InnoDB usa para dados do cache e ndices nas suas tabelas.';
@@ -388,7 +375,7 @@ $strInnoDBPages = 'pginas';
 $strInnoDBRelationAdded = 'Adicionado relacionamento InnoDB';
 $strInnodbStat = 'Status do InnoDB'; 
 $strInsecureMySQL = 'O seu arquivo de configurao contm configuraes (root sem senha) que correspondem  conta privilegiada padro do MySQL. O servidor MySQL rodando com esse padro estar aberto a invases, voc realmente deveria corrigir este furo de segurana.'; 
-$strInsertAsNewRow = 'Inserir uma nova coluna'; 
+$strInsertAsNewRow = 'Inserir como um novo registro'; 
 $strInsertedRowId = 'Inserir ID do registro:'; 
 $strInsertedRows = 'Registros inseridos:'; 
 $strInsert = 'Inserir'; 
@@ -398,7 +385,7 @@ $strInternalRelations = 'Relaes internas';
 $strInUse = 'em uso'; 
 $strInvalidAuthMethod = 'Mtodo de autenticao invlido informado nas configuraes:';
 $strInvalidColumn = 'Coluna especificada (%s)  invlida!';
-$strInvalidColumnCount = 'Contador da coluna deve ser mais largo que zero.';
+$strInvalidColumnCount = 'Contador da coluna deve ser maior que zero.';
 $strInvalidCSVFieldCount = 'Contador de campo invlido na linha %d da entrada CSV.';
 $strInvalidCSVFormat = 'Formato invlido na linha %d da entrada CSV.';
 $strInvalidCSVParameter = 'Parmetro invlido para importao CSV: %s';
@@ -425,7 +412,6 @@ $strKnownExternalBug = 'A funcionalidade %s  afetada por um bug conhecido, veja
 $strKorean = 'Coreano'; 
 
 $strLandscape = 'Paisagem'; 
-$strLanguageFileNotFound = 'Arquivo da linguagem "%1$s" no encontrado.';
 $strLanguage = 'Linguagem';
 $strLanguageUnknown = 'Linguagem desconhecida: %1$s.';
 $strLatchedPages = 'Pginas trancadas';
@@ -436,11 +422,9 @@ $strLatexContinued = '(continuao)';
 $strLatexIncludeCaption = 'Incluir legenda da tabela'; 
 $strLatexLabel = 'Rtulo da chave'; 
 $strLaTeX = 'LaTeX'; 
-$strLaTeXOptions = 'Opes LaTeX'; 
 $strLatexStructure = 'Estrutura da tabela __TABLE__'; 
 $strLatvian = 'Letons'; 
 $strLDI = 'CSV usando LOAD DATA';
-$strLDIImportOptions = 'Opes para importao CSV usando LOAD DATA';
 $strLDILocal = 'Usar palavra-chave LOCAL';
 $strLengthSet = 'Tamanho/Definir*'; 
 $strLimitNumRows = 'registros por pgina'; 
@@ -497,6 +481,7 @@ $strMyISAMSortBufferSize = 'Tamanho do buffer de ordenao';
 $strMySQLCharset = 'Conjunto de caracteres MySQL'; 
 $strMysqlClientVersion = 'Verso do cliente MySQL';
 $strMySQLConnectionCollation = 'Collation de conexo do MySQL'; // Collation nao tem traducao
+$strMysqlLibDiffersServerVersion = 'Sua verso %s da biblioteca MySQL do PHP difere da verso %s do seu servidor MySQL. Isso pode causar um comportamento estranho.';
 $strMySQLSaid = 'Mensagens do MySQL : '; 
 $strMySQLShowProcess = 'Mostrar os Processos'; 
 $strMySQLShowStatus = 'Mostrar informao de runtime do MySQL'; 
@@ -543,13 +528,12 @@ $strNumTables = 'Tabelas';
 
 $strOK = 'OK'; 
 $strOpenDocumentSpreadsheet = 'Abrir Documento Planilha';
-$strOpenDocumentSpreadsheetOptions = 'Abrir opes do Documento Planilha';
 $strOpenDocumentText = 'Abrir Documento de Texto';
-$strOpenDocumentTextOptions = 'Abrir opes do Documento de Texto';
 $strOpenNewWindow = 'Abrir nova janela do phpMyAdmin';
 $strOperations = 'Operaes'; 
 $strOperator = 'Operador'; 
 $strOptimizeTable = 'Otimizar tabela'; 
+$strOptions = 'Opes';
 $strOr = 'Ou'; 
 $strOverhead = 'Sobrecarga'; 
 $strOverwriteExisting = 'Sobrescrever arquivo(s) existente(s)'; 
@@ -567,7 +551,6 @@ $strPassword = 'Senha';
 $strPdfDbSchema = 'Esquema do Banco de Dados "%s" - Pgina %s'; 
 $strPdfInvalidTblName = 'A tabela "%s" no existe!'; 
 $strPdfNoTables = 'Sem tabelas'; 
-$strPDFOptions = 'Opes PDF';
 $strPDF = 'PDF';
 $strPDFReportExplanation = '(Gerado um relatrio contendo dados da tabela simples)';
 $strPDFReportTitle = 'Ttulo do Relatrio';
@@ -676,21 +659,24 @@ $strReplaceTable = 'Substituir os dados da tabela pelos do arquivo';
 $strReplication = 'Replicao';
 $strReset = 'Resetar'; 
 $strResourceLimits = 'Limite dos recursos'; 
+$strRestartInsertion = 'Reiniciar insero com %s registros';
 $strReType = 'Re-digite'; 
 $strRevokeAndDeleteDescr = 'Os usurios mantero o privilgio de USAGE at que os privilgios sejam recarregados.'; 
 $strRevokeAndDelete = 'Revogar todos os privilgios ativos dos usuarios e depois apagar eles.'; 
 $strRevokeMessage = 'Voc revogou os privilgios para %s'; 
 $strRevoke = 'Revogar'; 
 $strRomanian = 'Romno'; 
-$strRowLength = 'Tamanho da coluna'; 
-$strRows = 'Colunas'; 
-$strRowsFrom = 'colunas comeando de'; 
+$strRoutineReturnType = 'Tipo de returno';
+$strRoutines = 'Rotinas';
+$strRowLength = 'Tamanho do registro'; 
+$strRowsFrom = 'registro(s) comeando de'; 
 $strRowSize = ' Tamanho do registro '; 
 $strRowsModeFlippedHorizontal = 'horizontal (cabealhos rotacionados)'; 
 $strRowsModeHorizontal = 'horizontal'; 
 $strRowsModeOptions = 'no modo %s e repetindo cabealhos aps %s clulas'; 
 $strRowsModeVertical = 'vertical'; 
-$strRowsStatistic = 'Estatsticas da coluna'; 
+$strRows = 'Registros'; 
+$strRowsStatistic = 'Estatsticas do registros'; 
 $strRunning = 'Rodando em %s'; 
 $strRunQuery = 'Enviar consulta SQL'; 
 $strRunSQLQuery = 'Fazer consulta SQL no Banco de Dados %s'; 
@@ -733,6 +719,7 @@ $strServerTabVariables = 'Variveis';
 $strServerTrafficNotes = '<b>Trfico do servidor</b>: Essas tabelas mostram as estatsticas do trfico da rede neste servidor MySQL desde o incio.'; 
 $strServerVars = 'Variveis e configuraes do servidor'; 
 $strServerVersion = 'Verso do Servidor'; 
+$strSessionStartupErrorGeneral = 'No pde iniciar a sesso sem erros, cheque os erros ocorridos nos logs do PHP e/ou do seu servidor web e configure a instalao do PHP corretamente.';
 $strSessionValue = 'Valor da sesso'; 
 $strSetEnumVal = 'Se um tipo de campo  "enum" ou "set", por favor entre valores usando este formato: \'a\',\'b\',\'c\'...<br />Se voc for colocar uma barra contrria ("\") ou aspas simples ("\'") entre os valores, coloque uma barra contrria antes (por exemplo \'\\\\xyz\' ou \'a\\\'b\').'; 
 $strShowAll = 'Mostrar todos'; 
@@ -822,7 +809,7 @@ $strShowStatusKey_readsDescr = 'O nmero de leituras fsicas de um bloco chave do
 $strShowStatusKey_write_requestsDescr = 'O nmero de requisies para escrever um bloco chave para o cache.';
 $strShowStatusKey_writesDescr = 'O nmero de escritas fsicas para um bloco chave para o disco.';
 $strShowStatusLast_query_costDescr = 'O custo total da ltima consulta compilada como computado pelo otimizador de consultas. til para comparar o custo de diferentes planos de consulta para a mesma consulta. O valor padro 0 significa que nenhuma consulta foi compilada ainda.';
-$strShowStatusNot_flushed_delayed_rowsDescr = 'O nmero de linhas esperando para serem escritas na fila de INSERT DELAY.';
+$strShowStatusNot_flushed_delayed_rowsDescr = 'O nmero de linhas esperando para serem escritas na fila de INSERT DELAYED.';
 $strShowStatusOpened_tablesDescr = 'O nmero de tabelas que devem estar abertas. Se aberta, as tabelas so grandes, o valor do cache de suas tabelas  provavelmente muito pequeno.';
 $strShowStatusOpen_filesDescr = 'O nmero de arquivos que esto abertos.';
 $strShowStatusOpen_streamsDescr = 'O nmero de streams que esto abertos (usados principalmente para log).';
@@ -877,8 +864,6 @@ $strSpanish = 'Espanhol';
 $strSplitWordsWithSpace = 'Palavras so separadas por um caracter de espao (" ").'; 
 $strSQLCompatibility = 'Modo de compatibilidade SQL';
 $strSQLExportType = 'Tipo de exportao'; 
-$strSQLImportOptions = 'Opes SQL';
-$strSQLOptions = 'Opes SQL'; 
 $strSQLParserBugMessage = 'Talvez tenha encontrado um bug no analizador (parser) do SQL. Analise a sua Consulta SQL com ateno, e verifique se as aspas esto corretas e no esto desencontradas. Outra possibilidade de falha  o fato de estar tentando subir um arquivo com sada binria de uma rea de texto citada. Pode tambm experimentar a sua consulta SQL no prompt de comandos do MySQL. A sada de erro do MySQL, isto se existir alguma, tambm poder ajudar a diagnosticar o problema. Se continuar a ter problemas ou se o analisador (parser) falhar onde a interface da linha de comandos tiver sucesso, reduza por favor a entrada da consulta SQL at aquele que causou o problema, e envie o relatrio de bug com os dados do chunk da seo CORTE abaixo:'; 
 $strSQLParserUserError = 'Parece haver um erro na sua consulta SQL. A sada do servidor MySQL abaixo, isto se existir alguma, tambm poder ajudar a diagnosticar o problema.'; 
 $strSQLQuery = 'consulta SQL'; 
@@ -900,7 +885,6 @@ $strStrucCSV = 'Dados CSV';
 $strStrucData = 'Estrutura e dados'; 
 $strStrucExcelCSV = 'CSV para dados MS Excel'; 
 $strStrucNativeExcel = 'Dados nativos do MS Excel'; 
-$strStrucNativeExcelOptions = 'Opes de exportao nativa do Excel';
 $strStrucOnly = 'Somente estrutura'; 
 $strStructPropose = 'Propor estrutura da tabela'; 
 $strStructure = 'Estrutura'; 
@@ -966,6 +950,7 @@ $strTransformation_text_plain__imagelink = 'Mostrar uma imagem e um link, o camp
 $strTransformation_text_plain__link = 'Mostrar um link, o campo contm o nome do arquivo, primeira opo  um prefixo tipo "http://domain.com/", segunda opo  um ttulo para o link.'; 
 $strTransformation_text_plain__sql = 'Formatar texto como consulta SQL com sntaxe colorida.';
 $strTransformation_text_plain__substr = 'Mostrar apenas parte da string. Primeira opo  um offset para definir onde a sada do seu texto deve iniciar (Padro: 0). Segunda opo  o quanto do texto dever ser retornado. Se estiver em branco, retorna todo o restante do texto. Terceira opo define quais caracteres sero acrescentados na substring retornada (Padro: ...).'; 
+$strTriggers = 'Gatilhos';
 $strTruncateQueries = 'Truncar as consultas SQL exibidas'; 
 $strTurkish = 'Turco'; 
 $strType = 'Tipo'; 
@@ -982,6 +967,13 @@ $strUpdateProfileMessage = 'A configurao foi atualizada.';
 $strUpdateQuery = 'Atualizar a consulta SQL'; 
 $strUpdComTab = 'Consulte a documentao sobre como atualizar sua tabela Column_comments'; 
 $strUpgrade = 'Voc deveria atualizar para %s %s ou posterior.'; 
+$strUploadErrorCantWrite = 'Falhou ao salvar arquivo no disco.';
+$strUploadErrorExtension = 'Carregamento do arquivo parado pela exteno.';
+$strUploadErrorFormSize = 'O arquivo carregado excede o tamanho definido na diretriz MAX_FILE_SIZE do formulrio HTM.';
+$strUploadErrorIniSize = 'O arquivo carregado excede o tamanho definido na diretriz upload_max_filesize no php.ini.';
+$strUploadErrorNoTempDir = 'Pasta temporria no encontrada.';
+$strUploadErrorPartial = 'Carregamento do arquivo foi apenas parcial.';
+$strUploadErrorUnknown = 'Erro desconhecido no carregamento do arquivo.';
 $strUploadLimit = 'Voc provavelmente tentou carregar um arquivo muito grande. Veja referncias na %sdocumentation%s para burlar esses limites.';
 $strUploadsNotAllowed = 'No  permitido subir arquivos neste servidor.';
 $strUsage = 'Uso'; 
@@ -1011,6 +1003,7 @@ $strViewDumpDB = 'Ver o esquema do Banco de Dados';
 $strViewDump = 'Ver o esquema da tabela'; 
 $strViewHasBeenDropped = 'Viso %s foi apagada';
 $strViewMaxExactCount = 'Essa viso tem mais que %s linhas. Veja referncias na %sdocumentation%s.';
+$strViewName = 'Nome da VISO';
 $strView = 'Viso';
 
 $strWebServerUploadDirectoryError = 'O diretrio que voc especificou para subir arquivos no foi encontrado.'; 
@@ -1023,7 +1016,6 @@ $strWithChecked = 'Com marcados:';
 $strWriteRequests = 'Escrita requisitada';
 $strWrongUser = 'Usurio ou senha incorreta. Acesso negado.'; 
 
-$strXMLOptions = 'Opes XML';
 $strXML = 'XML'; 
 
 $strYes = 'Sim'; 
@@ -1031,4 +1023,6 @@ $strYes = 'Sim';
 $strZeroRemovesTheLimit = 'Nota: Ajustar essa opo para 0 (zero) remove os limites.'; 
 $strZip = '"compactado com zip"'; 
 
+$strProfiling = 'Profiling';  //to translate
+$strSuhosin = 'Server running with Suhosin. Please refer to %sdocumentation%s for possible issues.';  //to translate
 ?>
