@@ -1,5 +1,5 @@
 <?php
-/* $Id: french-iso-8859-15.inc.php 10490 2007-07-16 13:08:28Z lem9 $ */
+/* $Id$ */
 
 $charset = 'iso-8859-15';
 $text_dir = 'ltr';
@@ -35,7 +35,7 @@ $strAddNewField = 'Ajouter un champ';
 $strAddPrivilegesOnDb = 'Ajouter des privilges sur cette base de donnes';
 $strAddPrivilegesOnTbl = 'Ajouter des privilges sur cette table';
 $strAddSearchConditions = 'Critres de recherche (pour l\'nonc "where"):';
-$strAddToIndex = 'Ajouter  la clef&nbsp;%s&nbsp;colonne(s)';
+$strAddToIndex = 'Ajouter  l\'index&nbsp;%s&nbsp;colonne(s)';
 $strAddUser = 'Ajouter un utilisateur';
 $strAddUserMessage = 'Vous avez ajout un utilisateur';
 $strAdministration = 'Administration';
@@ -110,7 +110,7 @@ $strCanNotLoadImportPlugins = 'Chargement impossible des greffons d\'importation
 $strCannotLogin = 'Connexion au serveur MySQL non permise';
 $strCantLoad = 'PHP ne peut charger l\'extension %s, [br]veuillez vrifier votre configuration de PHP';
 $strCantLoadRecodeIconv = 'Erreur lors du chargement de l\'extension iconv ou recode, utilise pour convertir le jeu de caractres; veuillez activer l\'une de ces extensions dans PHP, ou dsactiver la conversion des jeux de caractres dans phpMyAdmin';
-$strCantRenameIdxToPrimary = 'La clef ne peut tre renomme PRIMARY&nbsp;!';
+$strCantRenameIdxToPrimary = 'L\'index ne peut tre renomm PRIMARY!';
 $strCantUseRecodeIconv = 'Erreur lors de l\'utilisation de iconv, libiconv et recode_string, alors que ces extensions semblent charges. Veuillez vrifier votre configuration de PHP.';
 $strCardinality = 'Cardinalit';
 $strCaseInsensitive = 'insensible  la casse';
@@ -163,8 +163,8 @@ $strCopyTableSameNames = 'On ne peut copier la table sur elle-mme!';
 $strCouldNotKill = 'phpMyAdmin n\'a pu liminer le processus %s. Il tait probablement dj ferm.';
 $strCreate = 'Crer';
 $strCreateDatabaseBeforeCopying = 'Faire CREATE DATABASE avant la copie';
-$strCreateIndex = 'Crer une clef sur&nbsp;%s&nbsp;colonne(s)';
-$strCreateIndexTopic = 'Crer un nouvelle clef';
+$strCreateIndex = 'Crer un index sur&nbsp;%s&nbsp;colonne(s)';
+$strCreateIndexTopic = 'Crer un nouvel index';
 $strCreateNewDatabase = 'Crer une base de donnes';
 $strCreateNewTable = '<b>Crer une nouvelle table</b> sur la base %s';
 $strCreatePage = 'Crer une page';
@@ -360,8 +360,8 @@ $strIndexes = 'Index';
 $strIndexesSeemEqual = 'Les index suivants semblent quivalents, vous devriez en liminer un.';
 $strIndexHasBeenDropped = 'L\'index %s a t effac';
 $strIndex = 'Index';
-$strIndexName = 'Nom de la clef&nbsp;:';
-$strIndexType = 'Type de clef&nbsp;:';
+$strIndexName = 'Nom de l\'index&nbsp;:';
+$strIndexType = 'Type d\'index&nbsp;:';
 $strIndexWarningTable = 'Il y a des problmes avec les index de la table `%s`';
 $strInnoDBAutoextendIncrement = 'Auto-croissant: Taille de l\'incrment';
 $strInnoDBAutoextendIncrementDesc = 'La valeur de l\'incrment lors de l\'agrandissement du fichier auto-croissant lorsqu\'il devient plein.';
@@ -405,7 +405,7 @@ $strJustDelete = 'Seulement effacer les utilisateurs des tables de privilges.';
 
 $strKeepPass = 'Conserver le mot de passe';
 $strKeyCache = 'Cache des cls';
-$strKeyname = 'Nom de la cl';
+$strKeyname = 'Nom de l\'index';
 $strKill = 'Supprimer';
 $strKnownExternalBug = 'La fonctionnalit %s est affecte par une anomalie connue, voir %s';
 $strKorean = 'coren';
@@ -458,7 +458,7 @@ $strMIME_transformation = 'Transformation';
 $strMIMETypesForTable = 'TYPES MIME POUR LA TABLE';
 $strMIME_without = 'Les types MIME affiches en italiques ne possdent pas de fonctions de transformation.';
 $strModifications = 'Les modifications ont t sauvegardes.';
-$strModifyIndexTopic = 'Modifier une clef';
+$strModifyIndexTopic = 'Modifier un index';
 $strModify = 'Modifier';
 $strMoveMenu = 'Dplacer le menu';
 $strMoveTable = '<b>Dplacer</b> la table vers (base<b>.</b>table)&nbsp;:';
@@ -498,8 +498,8 @@ $strNoDropDatabases = 'La commande "DROP DATABASE" est dsactive.';
 $strNoExplain = 'Ne pas expliquer SQL';
 $strNoFilesFoundInZip = 'Aucun fichier prsent dans l\'archive ZIP!';
 $strNoFrames = 'L\'utilisation de phpMyAdmin est plus aise avec un navigateur <b>supportant les "frames"</b>.';
-$strNoIndex = 'Aucune clef n\'est dfinie&nbsp;!';
-$strNoIndexPartsDefined = 'Aucune colonne n\'a t dfinie pour cette clef&nbsp;!';
+$strNoIndex = 'Aucun index n\'est dfini&nbsp;!';
+$strNoIndexPartsDefined = 'Aucune colonne n\'a t dfinie pour cet index&nbsp;!';
 $strNoModification = 'Pas de modifications';
 $strNone = 'aucune';
 $strNo = 'Non';
@@ -561,7 +561,7 @@ $strPhoneBook = 'annuaire tlphonique';
 $strPHP40203 = 'Vous utilisez PHP 4.2.3, et cette version a un srieux problme avec les caractres multi-octets (mbstring), tel que dcrit sur le rapport d\'anomalies 19404 chez PHP.  Il n\'est pas recommand d\'utiliser cette version de PHP avec phpMyAdmin.';
 $strPhp = 'Crer source PHP';
 $strPHPVersion = 'Version de PHP';
-$strPleaseSelectPrimaryOrUniqueKey = 'Veuillez choisir la cl primaire ou une cl unique';
+$strPleaseSelectPrimaryOrUniqueKey = 'Veuillez choisir la cl primaire ou un index unique';
 $strPmaDocumentation = 'Documentation de phpMyAdmin';
 $strPmaUriError = 'Le paramtre <tt>$cfg[\'PmaAbsoluteUri\']</tt> DOIT tre renseign dans votre fichier de configuration !';
 $strPmaWiki = 'Wiki phpMyAdmin';
@@ -570,8 +570,8 @@ $strPortrait = 'Portrait';
 $strPos1 = 'Dbut';
 $strPrevious = 'Prcdent';
 $strPrimaryKeyHasBeenDropped = 'La cl primaire a t efface';
-$strPrimaryKeyName = 'Le nom d\'une clef primaire doit tre PRIMARY&nbsp;!';
-$strPrimaryKeyWarning = '("PRIMARY" <b>doit et ne peut tre</b> que le nom d\'une clef primaire&nbsp;!)';
+$strPrimaryKeyName = 'Le nom d\'une cl primaire doit tre PRIMARY!';
+$strPrimaryKeyWarning = '("PRIMARY" <b>doit et ne peut tre</b> que le nom d\'une cl primaire&nbsp;!)';
 $strPrimary = 'Primaire';
 $strPrint = 'Imprimer';
 $strPrintViewFull = 'Version imprimable (avec textes complets)';
@@ -630,7 +630,7 @@ $strQueryOnDb = 'Requte SQL sur la base <b>%s</b>&nbsp;:';
 $strQueryResultsOperations = 'Oprations sur les rsultats de la requte';
 $strQuerySQLHistory = 'Historique SQL';
 $strQueryStatistics = '<b>Statistiques sur les requtes</b>: Depuis son dmarrage, %s requtes ont t envoyes au serveur.';
-$strQueryTime = 'traitement: %01.4f sec.';
+$strQueryTime = 'Traitement en %01.4f sec.';
 $strQueryType = 'Type de requte';
 $strQueryWindowLock = 'Ne pas craser cette requte depuis une autre fentre';
 
@@ -1023,4 +1023,5 @@ $strYes = 'Oui';
 $strZeroRemovesTheLimit = 'Note: Une valeur de 0 (zero) enlve la limite.';
 $strZip = '"zipp"';
 
+$strSuhosin = 'Server running with Suhosin. Please refer to %sdocumentation%s for possible issues.';  //to translate
 ?>
