@@ -1,5 +1,5 @@
 <?php
-/* $Id: slovak-windows-1250.inc.php 9853 2007-01-19 18:14:44Z lem9 $ */
+/* $Id$ */
 
 /* By: lubos klokner <erkac@vault-tec.sk> */
 /* and Ivan Kuriscak <shylauda69@yahoo.com>
@@ -7,7 +7,7 @@
 
 $charset = 'windows-1250';
 $text_dir = 'ltr';
-$number_thousands_separator = ' ';
+$number_thousands_separator = '';
 $number_decimal_separator = ',';
 // shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
 $byteUnits = array('Bajtov', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB');
@@ -65,7 +65,6 @@ $strAscending = 'Vzostupne';
 $strAtBeginningOfTable = 'Na zaiatku tabuky';
 $strAtEndOfTable = 'Na konci tabuky';
 $strAttr = 'Atribty';
-$strAutodetect = 'Automaticky zisti';
 $strAutomaticLayout = 'Automatick rozvrhnutie';
 
 $strBack = 'Sp';
@@ -176,8 +175,6 @@ $strCreationDates = 'Dtum vytvorenia, poslednej zmeny a kontroly';
 $strCriteria = 'Kritria';
 $strCroatian = 'Chorvtsky';
 $strCSV = 'CSV';
-$strCSVImportOptions = 'Monosti CSV';
-$strCSVOptions = 'Nastavenia pre CSV';
 $strCyrillic = 'Cyrilika';
 $strCzech = 'esky';
 $strCzechSlovak = 'etina/Slovenina';
@@ -187,7 +184,6 @@ $strDatabase = 'Databza';
 $strDatabaseEmpty = 'Meno databzy je przdne!';
 $strDatabaseExportOptions = 'Nastavenia exportu databz';
 $strDatabaseHasBeenDropped = 'Databza %s bola zmazan.';
-$strDatabaseNoTable = 'Tto databza neobsahuje iadne tabuky!';
 $strDatabases = 'Databzy';
 $strDatabasesDropped = 'spene zruench databz: %s.';
 $strDatabasesStatsDisable = 'Skry tatistiky';
@@ -261,7 +257,6 @@ $strEscapeWildcards = 'Nhradzujcim znakom _ a % by mal predchdza znak \, pokia i
 $strEsperanto = 'Esperanto';
 $strEstonian = 'Estnsky';
 $strExcelEdition = 'Verzia Excelu';
-$strExcelOptions = 'Nastavenia CSV pre Excel';
 $strExecuteBookmarked = 'Spusti obben dopyt';
 $strExplain = 'Vysvetli SQL';
 $strExport = 'Exportova';
@@ -272,7 +267,6 @@ $strExtra = 'Extra';
 $strFailedAttempts = 'Nepodarench pokusov';
 $strFieldHasBeenDropped = 'Pole %s bolo odstrnen';
 $strField = 'Pole';
-$strFieldsEmpty = ' Poet pol je przdny! ';
 $strFieldsEnclosedBy = 'Polia uzatvoren';
 $strFieldsEscapedBy = 'Polia uveden pomocou';
 $strFields = 'Polia';
@@ -318,15 +312,12 @@ $strHasBeenAltered = 'bola zmenen.';
 $strHasBeenCreated = 'bola vytvoren.';
 $strHaveToShow = 'Zvolte prosm aspo jeden stpec, ktor chcete zobrazi';
 $strHebrew = 'Hebrejsky';
-$strHexForBinary = 'Binrne pole vypisova v estnstkovej sstave';
 $strHome = 'Domov';
 $strHomepageOfficial = 'Oficilne strnky phpMyAdmin';
 $strHostEmpty = 'Nzov hostitea je przdny!';
 $strHost = 'Hostite';
 $strHTMLExcel = 'Microsoft Excel 2000';
-$strHTMLExcelOptions = 'Nastavenia pre Microsoft Excel 2000';
 $strHTMLWord = 'Microsoft Word 2000';
-$strHTMLWordOptions = 'Nastavenia pre Microsoft Word 2000';
 $strHungarian = 'Maarsky';
 
 $strIcelandic = 'Islandina';
@@ -344,10 +335,7 @@ $strIndexHasBeenDropped = 'Index pre %s bol odstrnen';
 $strIndex = 'Index';
 $strIndexName = 'Meno indexu&nbsp;:';
 $strIndexType = 'Typ indexu&nbsp;:';
-$strIndexWarningMultiple = 'Pre stpec `%s` je vytvoren viac ako jeden %s k';
-$strIndexWarningPrimary = 'Na stpec `%s` by nemal by nastaven PRIMARY a zrove INDEX k';
 $strIndexWarningTable = 'Problmy s indexami v tabuke `%s`';
-$strIndexWarningUnique = 'Na stpec `%s` by nemal by nastaven UNIQUE a zrove INDEX k';
 $strInnoDBAutoextendIncrementDesc = ' Vekos, o ktor je zven automaticky sa zvujci priestor tabuky pri zaplnen.';
 $strInnoDBAutoextendIncrement = 'Navenie pri automatickom zvovan';
 $strInnoDBBufferPoolSizeDesc = 'Vekos pamte, ktor InnoDB pouva pre cachovanie dt a indexov tabuliek.';
@@ -393,7 +381,6 @@ $strKill = 'Zabi';
 $strKorean = 'Krejina';
 
 $strLandscape = 'Na rku';
-$strLanguageFileNotFound = 'Jazykov sbor "%1$s" nebol njden.';
 $strLanguageUnknown = 'Neznmy jazyk: %1$s.';
 $strLatchedPages = 'Uzavretch strnok';
 $strLatexCaption = 'Nadpis tabuky';
@@ -403,11 +390,9 @@ $strLatexContinued = '(pokraovanie)';
 $strLatexIncludeCaption = 'Zahrn nadpis tabuky';
 $strLatexLabel = 'Nvestie';
 $strLaTeX = 'LaTeX';
-$strLaTeXOptions = 'Nastavenia pre LaTeX';
 $strLatexStructure = 'truktra tabuky __TABLE__';
 $strLatvian = 'Lotystina';
 $strLDI = 'CSV pomocou LOAD DATA';
-$strLDIImportOptions = 'Nastavenia CSV importu pomocou LOAD DATA';
 $strLDILocal = 'Poui kov slovo LOCAL';
 $strLengthSet = 'Dka/Nastavi*';
 $strLimitNumRows = 'zznamov na strnku';
@@ -507,10 +492,8 @@ $strNumSearchResultsTotal = '<b>Celkovo:</b> <i>%s</i> vskyt(ov)';
 $strNumTables = 'Tabuky';
 
 $strOK = 'OK';
-$strOpenDocumentSpreadsheetOptions = 'Nastavenia pre tabukov procesor Open Document';
 $strOpenDocumentSpreadsheet = 'Tabukov procesor Open Document';
 $strOpenDocumentText = 'Open Document Text';
-$strOpenDocumentTextOptions = 'Nastavenia pre Open Document Text';
 $strOpenNewWindow = 'Otvori nov okno phpMyAdmina';
 $strOperations = 'Opercie';
 $strOperator = 'Opertor';
@@ -532,7 +515,6 @@ $strPasswordNotSame = 'Hesl sa nezhoduj!';
 $strPdfDbSchema = 'Schma databzy "%s"  - Strana %s';
 $strPdfInvalidTblName = 'Tabuka "%s" neexistuje!';
 $strPdfNoTables = 'iadne tabuky';
-$strPDFOptions = 'Nastavenia pre PDF';
 $strPDF = 'PDF';
 $strPDFReportTitle = 'Titulok vpisu';
 $strPerHour = 'za hodinu';
@@ -774,7 +756,7 @@ $strShowStatusKey_readsDescr = 'Poet natan kovho bloku priamo z disku. Ak je tto
 $strShowStatusKey_write_requestsDescr = 'Poet poiadavkov na zpis kovho bloku do vyrovnvacej pamti.';
 $strShowStatusKey_writesDescr = 'Poet fyzickch zpisov kovho bloku na disk.';
 $strShowStatusLast_query_costDescr = 'Celkov nklady na posledn kompilovan prkaz, vypotan optimizrom prkazov. Uiton na porovnvanie nkladov na rzne prkazy pre t ist poiadavku. Prednastaven hodnota 0 znamen, e doposia neboli skompilovan iadne prkazy.';
-$strShowStatusNot_flushed_delayed_rowsDescr = 'Poet riadkov akajcich na zpis cez INSERT DELAY.';
+$strShowStatusNot_flushed_delayed_rowsDescr = 'Poet riadkov akajcich na zpis cez INSERT DELAYED.';
 $strShowStatusOpened_tablesDescr = 'Poet doposia otvorench tabuliek. Ak je tto hodnota prli vysok, pravdepodobne je vyrovnvacia pam pre tabuky prli mal.';
 $strShowStatusOpen_filesDescr = 'Poet otvorench sborov.';
 $strShowStatusOpen_streamsDescr = 'Poet otvorench streamov (vinou vyuvan na logovanie).';
@@ -828,8 +810,6 @@ $strSpanish = 'panielsky';
 $strSplitWordsWithSpace = 'Slov s rozdelen medzerou (" ").';
 $strSQLCompatibility = 'Reim kompatibility SQL';
 $strSQLExportType = 'Typ vytvorench dopytov';
-$strSQLImportOptions = 'Nastavenia SQL importu';
-$strSQLOptions = 'Nastavenia pre SQL';
 $strSQLParserBugMessage = 'Je mon, e ste nali chybu v SQL syntaktickom analyztore. Preskmajte podrobne SQL dopyt, predovetkm sprvnos umiestnenia vodzoviek. alia monos je, e nahrvate sbor s binrnymi dtami nezapsanmi v vodzovkch. Mete tie vyska poui prkazov riadok MySQL na odstrnenie problmu. Pokial stle mte problmy alebo syntaktick analyztor SQL stle hlsi chybu v dopyte, ktor v prkazovom riadku funguje, prosm pokste sa zredukova dopyt na o najmen, v ktorom sa problm ete vyskytuje a ohlste chybu na strnke phpMyAdmina spolu so sekciou VPIS uveden niie:';
 $strSQLParserUserError = 'Vyskytla sa chyba v SQL dopyte. Niie uveden MySQL vstup (ak je nejak) Vm me pomc odstrni problm';
 $strSQLQuery = 'SQL dopyt';
@@ -850,7 +830,6 @@ $strStrucCSV = 'CSV dta';
 $strStrucData = 'truktru a dta';
 $strStrucExcelCSV = 'CSV pre MS Excel dta';
 $strStrucNativeExcel = 'Natvne dta MS Excel';
-$strStrucNativeExcelOptions = 'Nastavenia pre natvny Excel';
 $strStrucOnly = 'Iba truktru';
 $strStructPropose = 'Navrhn truktru tabuky';
 $strStructure = 'truktra';
@@ -966,7 +945,6 @@ $strWithChecked = 'Vber:';
 $strWriteRequests = 'Poiadavkov na zpis';
 $strWrongUser = 'Zl pouvatesk meno alebo heslo. Prstup zamietnut.';
 
-$strXMLOptions = 'Nastavenia pre XML';
 $strXML = 'XML';
 
 $strYes = 'no';
@@ -983,7 +961,6 @@ $strLanguage = 'Language';  //to translate
 $strPmaWiki = 'phpMyAdmin wiki';  //to translate
 $strTransformation_text_plain__dateformat = 'Displays a TIME, TIMESTAMP, DATETIME or numeric unix timestamp field as formatted date. The first option is the offset (in hours) which will be added to the timestamp (Default: 0). Use second option to specify a different date/time format string. Third option determines whether you want to see local date or UTC one (use "local" or "utc" strings) for that. According to that, date format has different value - for "local" see the documentation for PHP\'s strftime() function and for "utc" it is done using gmdate() function.';  //to translate
 $strDocSQL = 'DocSQL';  //to translate
-$strDocSQLOptions = 'DocSQL options';  //to translate
 $strTableName = 'Table name';  //to translate
 $strTableIsEmpty = 'Table seems to be empty!';  //to translate
 $strDbIsEmpty = 'Database seems to be empty!';  //to translate
@@ -1028,4 +1005,27 @@ $strErrorRelationExists = 'Error: relation already exists.';  //to translate
 $strErrorSaveTable = 'Error saving coordinates for Designer.';  //to translate
 $strSnapToGrid = 'Snap to grid';  //to translate
 $strDesignerHelpDisplayField = 'The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.';  //to translate
+$strUploadErrorIniSize = 'The uploaded file exceeds the upload_max_filesize directive in php.ini.';  //to translate
+$strUploadErrorFormSize = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form.';  //to translate
+$strUploadErrorPartial = 'The uploaded file was only partially uploaded.';  //to translate
+$strUploadErrorNoTempDir = 'Missing a temporary folder.';  //to translate
+$strUploadErrorCantWrite = 'Failed to write file to disk.';  //to translate
+$strUploadErrorExtension = 'File upload stopped by extension.';  //to translate
+$strUploadErrorUnknown = 'Unknown error in file upload.';  //to translate
+$strSessionStartupErrorGeneral = 'Cannot start session without errors, please check errors given in your PHP and/or webserver log file and configure your PHP installation properly.';  //to translate
+$strFieldInsertFromFileTempDirNotExists = 'Error moving the uploaded file, see FAQ 1.11';  //to translate
+$strViewName = 'VIEW name';  //to translate
+$strOptions = 'Options';  //to translate
+$strFiles = 'Files';  //to translate
+$strIndexesSeemEqual = 'The following indexes appear to be equal and one of them should be removed:';  //to translate
+$strMysqlLibDiffersServerVersion = 'Your PHP MySQL library version %s differs from your MySQL server version %s. This may cause unpredictable behavior.';  //to translate
+$strRoutines = 'Routines';  //to translate
+$strRoutineReturnType = 'Return type';  //to translate
+$strControluserFailed = 'Connection for controluser as defined in your configuration failed.';  //to translate
+$strHexForBLOB = 'Use hexadecimal for BLOB';  //to translate
+$strRestartInsertion = 'Restart insertion with %s rows';  //to translate
+$strTriggers = 'Triggers';  //to translate
+$strEvent = 'Event';  //to translate
+$strProfiling = 'Profiling';  //to translate
+$strSuhosin = 'Server running with Suhosin. Please refer to %sdocumentation%s for possible issues.';  //to translate
 ?>
