@@ -1,5 +1,5 @@
-﻿<?php
-/* $Id: swedish-utf-8.inc.php 11124 2008-02-13 17:32:43Z lem9 $ */
+<?php
+/* $Id$ */
 
 /*
  * Translated by Björn T. Hallberg <bjornth at users.sourceforge.net>
@@ -1025,4 +1025,4 @@ $strYes = 'Ja';
 
 $strZeroRemovesTheLimit = 'Anm: Genom att sätta dessa alternativ till 0 (noll) tas begränsningarna bort.';
 $strZip = '"zippad"';
-?>
\ No newline at end of file
+?>
